@@ -26,6 +26,7 @@ from .tcpconnection import TCPConnection
 from .mqttconnection import MQTTConnection
 from .zmqconnection import ZMQConnection
 from .dashconnection import DashConnection
+from .load_config import decode_cfg64, encode_cfg64, load_controls_from_config
 # from .bleconnection import BLEConnection
 from .iotcontrol.enums import (
     Color,
@@ -35,7 +36,7 @@ from .iotcontrol.enums import (
     Keyboard,
     TextAlignment,
     TitlePosition,
-    SliderBarType,
+    SliderBarStyle,
     DialNumberPosition,
     DialStyle,
     GraphLineType,
@@ -50,8 +51,7 @@ from .iotcontrol.enums import (
     ColorPickerStyle
 )
 from .iotcontrol.graph import Graph, GraphLine
-from .iotcontrol.slider_single_bar import SliderSingleBar
-from .iotcontrol.slider_double_bar import SliderDoubleBar
+from .iotcontrol.slider import Slider
 from .iotcontrol.textbox import TextBox
 from .iotcontrol.button import Button
 from .iotcontrol.time_graph import TimeGraph, TimeGraphLine, DataPoint
