@@ -103,6 +103,8 @@ class Device(threading.Thread):
         data_array = data.split("\t")
         rx_device_id = data_array[0]
         if rx_device_id == "WHO":
+            if 'cfgRev' in self._cfg:
+                return self._device_id_str + f"\tWHO\t{self.device_type}\t{self.device_name}\t{self._cfg['cfgRev']}\n"
             return self._device_id_str + f"\tWHO\t{self.device_type}\t{self.device_name}\n"
         if rx_device_id != self.device_id:
             return ""
@@ -125,9 +127,9 @@ class Device(threading.Thread):
 
     def _make_status(self, _):
         reply = f"\t{self.device_id}\tNAME\t{self._device_name}\n"
-        for key in self._control_dict:
+        for value in self._control_dict.values():
             try:
-                reply += self._control_dict[key].get_state().format(device_id=self.device_id)
+                reply += value.get_state().format(device_id=self.device_id)
             except (TypeError, KeyError):
                 pass
         return reply
@@ -135,12 +137,17 @@ class Device(threading.Thread):
     def _make_cfg(self, data):
         try:
             dashboard_id = data[2]
-            no_views = data[3]
+            #  no_views = data[3]
         except IndexError:
-            return
+            return ""
         reply = self._device_id_str + f"\tCFG\t{dashboard_id}\tDVCE\t" + json.dumps(self._cfg) + "\n"
-        for key in self._control_dict:
-            reply += self._device_id_str + self._control_dict[key].get_cfg(data)
+        dvvw_str = ""
+        for value in self._control_dict.values():
+            if value.cntrl_type == "DVVW":
+                dvvw_str += self._device_id_str + value.get_cfg(data)
+            else:
+                reply += self._device_id_str + value.get_cfg(data)
+        reply += dvvw_str
         return reply
 
     def send_alarm(self, alarm_id, message_header, message_body):
@@ -397,6 +404,21 @@ class Device(threading.Thread):
     def number_of_device_views(self, val: int):
         self._cfg["numDeviceViews"] = val
 
+    @property
+    def config_revision(self) -> int:
+        """Sets the cfgRev number. Increment this number to indicate a new CFG
+
+        Returns
+        -------
+        int
+            The cfgRev number
+        """
+        return self._cfg["cfgRev"]
+
+    @config_revision.setter
+    def config_revision(self, val: int):
+        self._cfg["cfgRev"] = val
+
     @property
     def device_name(self) -> str:
         """Device name
