@@ -21,8 +21,8 @@ LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 SOFTWARE.
 """
-from .control import Control
-from .enums import Color, Icon
+from .control import Control, _get_color, _get_icon, _get_device_view_style
+from .enums import Color, Icon, DeviceViewStyle
 
 
 class DeviceView(Control):
@@ -36,6 +36,8 @@ class DeviceView(Control):
        Each control inherits the DeviceViews Control settings
     title : str
         The controls title
+    style : DeviceViewStyle
+        The style of the DeviceView
     icon : Icon
         The Icon representing the DeviceView
     color : Color
@@ -48,6 +50,10 @@ class DeviceView(Control):
         Title box color for controls
     control_title_box_transparency : int
         Title box transparency for controls
+    num_grid_columns : int
+        The num of grid columns on the edit view
+    num_grid_rows : int
+        The num of grid rows on the edit view
 
 
     Methods
@@ -60,36 +66,73 @@ class DeviceView(Control):
         self,
         control_id,
         title="A DeviceView",
+        style=DeviceViewStyle.BASIC,
         icon=Icon.SQUARE,
         color=Color.BLACK,
-        share_column = True,
-        num_columns = 1,
+        share_column=True,
+        num_columns=1,
         control_title_box_color=Color.BLACK,
         control_title_box_transparency=0,
         control_color=Color.WHITE_SMOKE,
         control_border_color=Color.WHITE_SMOKE,
-        control_border_on=False,
         control_background_color=Color.BLACK,
         control_title_font_size=16,
         control_max_font_size=20,
         control_background_transparency=0,
+        num_grid_columns=22,
+        num_grid_rows=32,
     ):
         super().__init__("DVVW", control_id, title=title)
         self.icon_name = icon
         self.color = color
         self.share_column = share_column
+        self.style = style
         self.num_columns = num_columns
         self.control_title_box_color = control_title_box_color
         self.control_title_box_transparency = control_title_box_transparency
         self.control_color = control_color
         self.control_border_color = control_border_color
-        self.control_border_on = control_border_on
         self.control_background_color = control_background_color
         self.control_title_font_size = control_title_font_size
         self.control_max_font_size = control_max_font_size
         self.control_background_transparency = control_background_transparency
+        self.num_grid_columns = num_grid_columns
+        self.num_grid_rows = num_grid_rows
         self._state_str = ""
 
+    @classmethod
+    def from_cfg_dict(cls, cfg_dict: dict):
+        """Instatiates DeviceView from cfg dictionary
+
+        Parameters
+        ----------
+        cfg_dict : dict
+            A dictionary usually loaded from a config json from IoTDashboard App
+
+        Returns
+        -------
+        DeviceView
+        """
+        return cls(
+            cfg_dict["controlID"],
+            cfg_dict["title"],
+            _get_icon(cfg_dict["iconName"]),
+            _get_color(cfg_dict["color"]),
+            cfg_dict["shareColumn"],
+            cfg_dict["numColumns"],
+            _get_color(cfg_dict["ctrlTitleBoxColor"]),
+            cfg_dict["ctrlTitleBoxTransparency"],
+            _get_color(cfg_dict["ctrlBorderColor"]),
+            _get_color(cfg_dict["ctrlColor"]),
+            _get_device_view_style(cfg_dict["style"]),
+            _get_color(cfg_dict["ctrlBkgndColor"]),
+            cfg_dict["ctrlTitleFontSize"],
+            cfg_dict["ctrlMaxFontSize"],
+            cfg_dict["ctrlBkgndTransparency"],
+            cfg_dict["gridColumns"],
+            cfg_dict["gridRows"]
+        )
+
     def add_control(self, control):
         """Add a control to the DeviceView
 
@@ -237,19 +280,19 @@ class DeviceView(Control):
         self._cfg["ctrlBorderColor"] = str(val.value)
 
     @property
-    def control_border_on(self) -> bool:
-        """Control border display
+    def style(self) -> DeviceViewStyle:
+        """Sets the style of the DeviceView
 
         Returns
         -------
-        bool
-            Set to true to display the contol borders
+        DeviceViewStyle
         """
-        return self._cfg["ctrlBorderOn"]
+        return self._style
 
-    @control_border_on.setter
-    def control_border_on(self, val: bool):
-        self._cfg["ctrlBorderOn"] = val
+    @style.setter
+    def style(self, val: DeviceViewStyle):
+        self._style = val
+        self._cfg["style"] = str(val.value)
 
     @property
     def control_background_color(self) -> Color:
@@ -314,3 +357,36 @@ class DeviceView(Control):
             self._cfg["ctrlBkgndTransparency"] = val
         else:
             raise ValueError("Value must be in the range 0 to 100")
+
+
+    @property
+    def num_grid_columns(self) -> int:
+        """Number of grid Columns
+
+        Returns
+        -------
+        int
+            the Number of grid Columns
+        """
+        return self._cfg["gridColumns"]
+
+    @num_grid_columns.setter
+    def num_grid_columns(self, val: int):
+        self._cfg["gridRows"] = val
+
+
+    @property
+    def num_grid_rows(self) -> int:
+        """The number of grid rows
+
+        Returns
+        -------
+        int
+            the number of grid rows
+        """
+        return self._cfg["gridRows"]
+
+    @num_grid_rows.setter
+    def num_grid_rows(self, val: int):
+        self._cfg["gridRows"] = val
+        
\ No newline at end of file
