@@ -25,7 +25,7 @@ import datetime
 import json
 import dateutil.parser
 from ..constants import BAD_CHARS
-from .control import Control
+from .control import Control, ControlPosition, _get_title_position
 from .enums import Color, TitlePosition
 from .ring_buffer import RingBuffer
 
@@ -108,14 +108,33 @@ class EventLog(Control):
         self.log = RingBuffer(max_log_entries)
 
 
+    @classmethod
+    def from_cfg_dict(cls, cfg_dict: dict):
+        """Instatiates Menu from cfg dictionary
+
+        Parameters
+        ----------
+        cfg_dict : dict
+            A dictionary usually loaded from a config json from IoTDashboard App
+
+        Returns
+        -------
+        Menu
+        """
+        return cls(
+            cfg_dict["controlID"],
+            cfg_dict["title"],
+            _get_title_position(cfg_dict["titlePosition"]),
+            ControlPosition(cfg_dict["xPositionRatio"], cfg_dict["yPositionRatio"], cfg_dict["widthRatio"], cfg_dict["heightRatio"])
+        )
+
     def _get_log_from_timestamp(self, msg):
         data_str = ""
         try:
             dashboard_id = msg[3]
-            from_timestamp = msg[4]
-        except IndexError:
+            from_date = dateutil.parser.isoparse(msg[4])
+        except (IndexError, ValueError):
             return ""
-        from_date = dateutil.parser.isoparse(from_timestamp)
         data_str += self._control_hdr_str + dashboard_id
         has_data = False
         for log in self.log.get():
